@@ -1,13 +1,10 @@
-// main.m					simpleCbug
+// SimpleCbug
 
 #import <simtools.h>
-#include <stdlib.h>
 
 int
 main(int argc, char ** argv) {
 
-  int random_move();
-
   int worldXSize = 80;			// Maximum X value
   int worldYSize = 80;			// Maximum Y value
 
@@ -24,8 +21,8 @@ main(int argc, char ** argv) {
 
     // Random movement in X and Y (possibly 0)
 
-    xPos = xPos + random_move();
-    yPos = yPos + random_move();
+    xPos = xPos + [uniformIntRand getIntegerWithMin: -1 withMax: 1];
+    yPos = yPos + [uniformIntRand getIntegerWithMin: -1 withMax: 1];
 
     // Take move modulo maximum coordinate values
 
@@ -39,18 +36,7 @@ main(int argc, char ** argv) {
   return 0;
 
 }
-
-int
-random_move() {
-  double randnum;
-
-  randnum = drand48();
-  
-  if (randnum <= 0.33333) return -1;
-  else if (randnum <= 0.6667) return 0;
-       else return 1;
-
-} 
+ 
  
 
 
