@@ -16,8 +16,8 @@
 
 // First, the interface for the ParameterManager
 
-@interface ParameterManager : SwarmObject {
-
+@interface ParameterManager : SwarmObject
+{
   int worldXSize;
   int worldYSize;
 
@@ -30,13 +30,13 @@
   float seedProbMax;
   float bugDensityMax;
 
-  ProbeMap * pmProbeMap;
+  id <ProbeMap> pmProbeMap;
 }
 
--initializeParameters;
--initializeModel: (ModelSwarm *) theModel;
--stepParameters;
--printParameters: (OutFile *) anOutFile;
+- initializeParameters;
+- initializeModel: theModel;
+- stepParameters;
+- printParameters: anOutFile;
 
 @end
 
@@ -45,8 +45,8 @@
 
 // Now, the Experiment Swarm Interface
 
-@interface ExperSwarm : GUISwarm {
-
+@interface ExperSwarm: GUISwarm
+{
   int modelTime;				// model run time
   int numModelsRun;				// number of models run
 
@@ -54,26 +54,26 @@
   id experSchedule;
 
   id modelZone;					// Zone for modelSwarm
-  ModelSwarm * modelSwarm;			// the Swarm we're iterating 
+  ModelSwarm *modelSwarm;			// the Swarm we're iterating 
 
-  ParameterManager * parameterManager; 		// An object to manage model
+  ParameterManager *parameterManager; 		// An object to manage model
 						// parameters
 
-  OutFile * logFile;				// File to log run results
+  id <OutFile> logFile;				// File to log run results
 
  // Display objects, widgets, etc.
 
-  EZGraph  * resultGraph;			// graphing widget
-  ProbeMap * modelProbeMap;			// the ProbeMap for the modelSwarm
+  EZGraph *resultGraph;				// graphing widget
+  id <ProbeMap> modelProbeMap;			// the ProbeMap for the modelSwarm
 }
 
 // Methods overriden to make the the Experiment Swarm
 
-+createBegin: (id) aZone;
--createEnd;
++ createBegin: aZone;
+- createEnd;
 
--buildObjects;
--buildActions;
--activateIn: (id) swarmContext;			// Context is self (ObserverSwarm).
+- buildObjects;
+- buildActions;
+- activateIn: swarmContext;			// Context is self (ObserverSwarm).
 
 @end
