@@ -12,8 +12,8 @@
 #import <simtools.h>
 
 
-@interface ModelSwarm: Swarm {
-
+@interface ModelSwarm: Swarm
+{
   int worldXSize, worldYSize;
 
   float seedProb;
@@ -21,29 +21,28 @@
 
   int time;
 
-  FoodSpace * foodSpace;
-  Grid2d * world;
+  FoodSpace *foodSpace;
+  Grid2d *world;
 
   id bugList;
   id modelActions;
   id modelSchedule;
-
 }
 
--getWorld;
--getFoodSpace;
--getBugList;
--(int)getTime;
+- getWorld;
+- getFoodSpace;
+- getBugList;
+- (int)getTime;
 
--setWorldXSize: (int) x YSize: (int) y;
--setSeedProb: (float) s bugDensity: (float) b;
+- setWorldXSize: (int)x YSize: (int)y;
+- setSeedProb: (float)s bugDensity: (float)b;
 
-+createBegin: (id) aZone;
--createEnd;
++ createBegin: aZone;
+- createEnd;
 
--buildObjects;
--buildActions;
--activateIn: (id) swarmContext;
+- buildObjects;
+- buildActions;
+- activateIn: swarmContext;
 
 @end
 
