@@ -3,17 +3,20 @@
 
 #import "ExperSwarm.h"
 
-#import <simtools.h>                // ... for initSwarm() 
+#import <simtools.h>                // ... for initSwarm () 
 
 int
-main(int argc, char ** argv) {
-  ExperSwarm * experSwarm;
+main (int argc, char **argv)
+{
+  ExperSwarm *experSwarm;
 
-  initSwarm(argc, argv);
+  initSwarm (argc, argv);
 
   // Make the experiment swarm
 
-  experSwarm =  [ExperSwarm create: globalZone];
+  experSwarm =  [ExperSwarm createBegin: globalZone];
+  SET_WINDOW_GEOMETRY_RECORD_NAME (experSwarm);
+  experSwarm = [experSwarm createEnd];
 
   // Now send messages to the newly created swarm telling it
   // to build its internal objects and its schedule.
