@@ -1,8 +1,6 @@
-// Bug.h					simpleObjCBug
+// Bug.h
 
 #import <swarmobject/SwarmObject.h>
-#import <simtools.h>
-
 
 @interface Bug: SwarmObject {
 
