@@ -1,8 +1,7 @@
-// Bug.h					simpleObjCBug2
+// Bug.h					SimpleBug
 
 #import <swarmobject/SwarmObject.h>
 #import <space.h>
-#import <simtools.h>
 
 @interface Bug: SwarmObject {
 
@@ -10,14 +9,15 @@
   int worldXSize, worldYSize;
   
   id foodSpace;
+
 }
 
 -setWorldSizeX: (int) x Y: (int) y;
 -setFoodSpace: (id) f;
-
 -createEnd;
 
 -setX: (int) x Y: (int) y;
+
 -step;
 
 @end
