@@ -1,10 +1,8 @@
-// Bug.h					simpleObserverBug
-
-#import "FoodSpace.h"
+// Bug.h					SimpleBug
 
 #import <swarmobject/SwarmObject.h>
 #import <space.h>
-#import <simtools.h>
+#import "FoodSpace.h"
 
 @interface Bug: SwarmObject {
 
@@ -12,7 +10,7 @@
   int worldXSize, worldYSize;
   
   Grid2d * world;
-  id foodSpace;
+  id food;
 
   int haveEaten;
 
