@@ -1,12 +1,13 @@
-// Bug.m					simpleObserverBug
+// Bug.m					SimpleBug
 
 #import "Bug.h"
+#import <simtools.h>
 
 @implementation Bug
 
 -setWorld: (id) w Food: (id) f {
    world = w;
-   foodSpace = f;
+   food = f;
    return self;
 }
 
@@ -42,8 +43,8 @@
     [world putObject: self atX: newX Y: newY];
   }
      
-  if ([foodSpace getValueAtX: xPos Y: yPos] == 1) {
-      [foodSpace putValue: 0 atX: xPos Y: yPos];
+  if ([food getValueAtX: xPos Y: yPos] == 1) {
+      [food putValue: 0 atX: xPos Y: yPos];
       haveEaten = 1; 
   }
 
