@@ -1,4 +1,4 @@
-// ModelSwarm.h					simpleObserverBug 
+// ModelSwarm.h					SimpleBug App
 
 #import "Bug.h"
 #import "FoodSpace.h"
@@ -7,8 +7,7 @@
 #import <activity.h>
 #import <collections.h>
 #import <tkobjc.h>
-#import <swarmobject.h>
-#import <simtools.h>
+#import <objectbase.h>
 
 
 @interface ModelSwarm: Swarm {
@@ -17,7 +16,7 @@
   float seedProb;
   float bugDensity;
 
-  FoodSpace * foodSpace;
+  FoodSpace * food;
   Grid2d * world;
 
   id bugList;
@@ -31,7 +30,6 @@
 
 +createBegin: (id) aZone;
 -createEnd;
-
 -buildObjects;
 -buildActions;
 -activateIn: (id) swarmContext;
