@@ -1,6 +1,7 @@
-// FoodSpace.m					simpleObserverBug2
+// FoodSpace.m
 
 #import "FoodSpace.h"
+#import <simtools.h>
 
 @implementation FoodSpace
 
@@ -9,7 +10,7 @@
 
   for (y = 0; y < ysize; y++) 
     for (x = 0; x < xsize; x++) 
-      if ([uniformDblRand getDoubleWithMin: 0.0 withMax: 1.0] <= seedProb) 
+      if ([uniformDblRand getDoubleWithMin: 0.0 withMax: 1.0] < seedProb) 
 	[self putValue: 1 atX: x Y: y];
 
   return self;
