@@ -1,6 +1,7 @@
-// Bug.m					simpleSwarmBug
+// Bug.m					SimpleBug
 
 #import "Bug.h"
+#import <simtools.h>
 
 @implementation Bug
 
