@@ -1,11 +1,8 @@
-// Bug.h					simpleSwarmBug2
-
-#import "FoodSpace.h"
+// Bug.h					SimpleBug
 
 #import <swarmobject/SwarmObject.h>
 #import <space.h>
-#import <simtools.h>
-
+#import "FoodSpace.h"
 
 @interface Bug: SwarmObject {
 
@@ -13,14 +10,13 @@
   int worldXSize, worldYSize;
   
   Grid2d * world;
-  id foodSpace;
+  id food;
 
   int haveEaten;
 
 }
 
 -setWorld: (id) w Food: (id) f;
-
 -createEnd;
 
 -setX: (int) x Y: (int) y;
